@@ -1,9 +1,9 @@
 /*
-    -- MAGMA (version 2.5.1) --
+    -- MAGMA (version 2.5.2) --
        Univ. of Tennessee, Knoxville
        Univ. of California, Berkeley
        Univ. of Colorado, Denver
-       @date August 2019
+       @date November 2019
 
        @precisions normal z -> c d s
        @author Chongxiao Cao
@@ -16,8 +16,6 @@
 #include <string.h>
 #include <math.h>
 
-#include <cuda.h>  // for CUDA_VERSION
-
 // includes, project
 #include "flops.h"
 #include "magma_v2.h"
